@@ -26,15 +26,12 @@
 #include <QBoxLayout>
 
 #include <KLocalizedString>
-#include <kdialog.h>
 
 #include <stdio.h>
 
 ImportsView::ImportsView(QWidget * parent, KConfig *config) :
 	QWidget(parent), configFile(config), list(this) {
 	QBoxLayout *topLayout = new QVBoxLayout(this);
-	topLayout->setMargin(KDialog::marginHint());
-	topLayout->setSpacing(KDialog::spacingHint());
 	topLayout->addWidget(&list);
 
 	list.setAllColumnsShowFocus(true);
